/*

 
 */
 
#ifndef cbi
#define cbi(sfr, bit) (_SFR_BYTE(sfr) &= ~_BV(bit))
#endif
#ifndef sbi
#define sbi(sfr, bit) (_SFR_BYTE(sfr) |= _BV(bit))
#endif

#ifndef NULL
#define NULL ((void *)0)
#endif

#ifndef bool
	typedef uint8_t bool;
#endif 

#define LOW 0
#define HIGH 1
#define false 0
#define true 1

#define T16MS 0
#define T32MS 1
#define T64MS 2
#define T128MS 3
#define T250MS 4
#define T500MS 5
#define T1S 6
#define T2S 7
#define T4S 8
#define T8S 9

// Sleep - powerdown
void system_sleep(void) {
	set_sleep_mode(SLEEP_MODE_PWR_DOWN); // Set sleep mode
	sleep_mode(); // System sleeps here
}

// Watchdog timeout values
// 0=16ms, 1=32ms, 2=64ms, 3=128ms, 4=250ms, 5=500ms, 6=1sec, 7=2sec, 8=4sec, 9=8sec
void setup_watchdog(uint8_t wdDelay) {
	if (wdDelay > 9) { 
		wdDelay = 9;
	}
	
	uint8_t bb = wdDelay & 7;
	if (wdDelay > 7) { 
		bb |= (1<<5);
	}
	
	MCUSR &= ~(1<<WDRF);
	// Start timed sequence
	WDTCSR |= (1<<WDE);
	// Set new watchdog timeout value
	WDTCSR = bb;
	WDTCSR |= _BV(WDIE);
}

// Turn off the Watchdog
void turnOffwatchdog(void) {
	cli(); // Turn interrupts off
	MCUSR &= ~(1<<WDRF);
	//CCP = 0xD8;
	WDTCSR = 0;
	sei(); // Turn interrupts back on
}

// Watchdog sleep function - combines all the above functions into one
void watchdog_sleep(uint8_t timeout) { 
	setup_watchdog(timeout);
	system_sleep();
	turnOffwatchdog();
}

// Setup
void setup(void) {
	// Set outputs
	DDRD |= (1<<PD3) | (1<<PD5) | (1<<PD6);
	DDRB |= (1<<PB3);
	
	// Set Timer0 fast PWM COM0A/B
	TCCR0A = (1<<COM0A1) | (1<<COM0A0) | (1<<COM0B1) | (1<<COM0B0) | (1<<WGM01) | (1<<WGM00);
	OCR0A = 255;
	OCR0B = 255;
	TCCR0B = (1<<CS02);
	
	// Set Timer2 fast PWM COM2A/B
	TCCR2A = (1<<COM2A1) | (1<<COM2A0) | (1<<COM2B1) | (1<<COM2B0) | (1<<WGM21) | (1<<WGM20);
	OCR2A = 255;
	OCR2B = 255;
	TCCR2B = (1<<CS22);
	
	// Initialse I2C rate	
	TWBR = 12;
	
	DDRC |= (1<<PC3);
	PORTC |= (1<<PC3);
	_delay_ms(500);
	PORTC &= ~(1<<PC3);
	
	sei(); // Turn on interrupts
}
